@@ -28,7 +28,7 @@ use Scalar::Util qw(blessed);
 
 # NOTE: due to CPAN version checks this cannot currently be changed to a
 # standard version string, i.e. '0.21'
-our $VERSION   = '46';
+our $VERSION   = '47';
 our $pre_link  = undef;
 our $fast_mode = undef;
 our %nagios_setup;
@@ -855,6 +855,12 @@ sub _set ($ $ $) {
         $self->_validate( $key, $value, @{ $vf->{$key} } );
     }
 
+    # Nagios allows the usage of a '+' sign. This breaks member lists.
+    # Ignore the '+' sign completely for now.
+    if ( ref $vf->{$key}[0] eq 'ARRAY' && $value =~/^\+(.+)$/ ) {
+        $value = $1;
+    }
+
     if ( ref $vf->{$key}[0] eq 'ARRAY' && $value =~ /,/ ) {
         $value = [ split /\s*,\s*/, $value ];
     }
@@ -953,6 +959,13 @@ sub _validate {
 # support "hostgroup" alongside "hostgroups" by piggybacking it
 sub hostgroup_name {
     my $self = shift;
+
+    # Since this method is available in all objects, perform a check in
+    # the config to see if its actually valid on the object
+    (my $type = ref $self) =~ s/.*:://;
+    if(!$nagios_setup{$type}{hostgroup_name}) {
+        return;
+    }
     if ( $self->can('hostgroup') ) {
         return $self->hostgroup(@_);
     }
